@@ -183,7 +183,9 @@ class ALXapp:
             ["-s", "--start", {"default": None, "type": str,
                                "help": "The first date from which to retrieve prices"}],
             ["-g", "--gui", {"action": "store_true", "default": False,
-                             "help": "Display the browser."}]
+                             "help": "Display the browser."}],
+            ["locations", {nargs='*', default=[],
+                           "help": "List of locations"}]
         ]
         ```
         but you can just use this trimmed down version to store the
@@ -258,7 +260,7 @@ class ALXapp:
         self.start_logging()
 
     @staticmethod
-    def parse_config(obj: object, config: configparser.SectionProxy):
+    def parse_config(obj: object, config: configparser.SectionProxy) -> object:
         """
         Parses the `config` and stores in `obj` as the appropriate type.
         It works out if it is a boolean, float, integer or string. If
@@ -315,10 +317,12 @@ class ALXapp:
          values (usually `self`)
         :param config: The `configparser` object.  It can be a section
         like `config[app.environment]`
+
+        :return: The object with typed configuration attributes added
         """
 
         try:
-            for item in config:
+            for item, value in config.items():
                 # Add all the config values as string values in the app
                 value = config.get(item)
                 if '$data' in value:
@@ -353,6 +357,52 @@ class ALXapp:
         except Exception:
             raise
 
+        return obj
+
+    def parse_config_section(self, obj: object, config: configparser.SectionProxy,
+                             include_defaults: bool = False) -> object:
+        """
+        Parse a config file section and store it in the object `obj`. This is
+        a wrapper for `parse_config` function to maintain compatibility
+        with `ALXapp.parse_config`.
+
+        :param obj: An object in which to store the configuration
+        :param config: The configparser object.  It can be a section
+         like `config[app.environment]`
+        :param include_defaults: Whether the values in the `[DEFAULT]` should
+        be parsed.
+
+        :return: The object with typed configuration attributes added
+        """
+
+        if include_defaults:
+            return self.parse_config(obj, config)
+        else:
+            # Get keys that are explicitly defined in the section (not from defaults)
+            section_keys = (set(self.config.options(config.name)) -
+                            set(self.config.defaults().keys()))
+
+            # Also include keys from defaults that have been overridden (different values)
+            for key in self.config.defaults().keys():
+                if key in config:
+                    default_value = self.config.defaults()[key]
+                    section_value = self.config.get(config.name, key, raw=True)
+                    if default_value != section_value:
+                        section_keys.add(key)
+
+            # Create a new ConfigParser with the same interpolation as the original
+            section_config = configparser.ConfigParser()
+            section_config.add_section('section')
+
+            for key in section_keys:
+                if key in config:
+                    # Get the raw value to preserve %% escaping
+                    raw_value = self.config.get(config.name, key, raw=True)
+                    section_config.set('section', key, raw_value)
+
+            # Pass the new SectionProxy to parse_config
+            return self.parse_config(obj, section_config['section'])
+        
     @staticmethod
     def read_config(filename: str, filename2: str = None):
         """
@@ -384,7 +434,7 @@ class ALXapp:
         On first invocation, the user files are checked and created if
         they don't exist.
 
-        :return: The `configparser.ConfigParser` configuration
+        :return: The merge `configparser.ConfigParser` configuration
         """
         if not hasattr(self, 'paths'):
             self.paths = Paths("alx-common")
