@@ -166,6 +166,10 @@ class ALXdatabase:
             log = "%s:\n%s" % (name, format_sql(sql))
         else:
             log = format_sql(sql)
+
+        if params:
+            log += "\nParams: %s" % (format(params))
+
         self.logger.debug(log)
 
         try:
@@ -184,7 +188,12 @@ class ALXdatabase:
             self.logger.error('SQL execution failed: %s', e)
             raise
 
-        if sql.lower().startswith("select"):
+        statement = sql.lower()
+        if statement.startswith("select") or \
+            statement.startswith("with") and "select" in statement or \
+            "returning" in statement:
+            # There are other statements like call, execute  values, show
+            # and explain that are not handled
             self.logger.debug("%d rows returned", self.cursor.rowcount)
             return self.cursor.fetchall()
 
